%
%  parameter stepping example 2:  Barium Ferrite
%
clear all;
close all;
format longe;
% make current value of lambda available globally
global pHi
%
% set up pH vector
%
phlo =1.0;
phhi = 7.0;
dph = 0.001;
nph = (phhi - phlo)/dph + 1;
phvec = zeros(nph,1);
phvec=[phlo:dph:phhi]';
%
%  reserve memory for solution matrix
%
solmat = zeros(nph,4);
%
%  initial guess for low pH 
%
citguess=4.411200613732259e-12;
feguess=3.960000000000000e-02;
baguess=2.500000000000000e-03;
no3nguess=3.448275862068966e-01;
x0=[citguess; feguess; baguess;no3nguess];
% set the tolerance and printing switch
tol=1.0e-8;
iprint=0; % 0 is off, 1 is on
%
%  parameter step
%
for i =1:1:nph
% call Newton-Raphson
    pHi = phvec(i);
    [x,err,f] = nrndn(x0,tol,iprint);
% store result
  solmat(i,1:4) = x(1:4);
  fmat(i) = f;
% update initial guess
  x0(1:4) = x(1:4);
end

%
%  plot result 
%
figure(1)
semilogy(phvec(1:nph),solmat(1:nph,1),'k-');
hold on;
semilogy(phvec(1:nph),solmat(1:nph,2),'r-');
hold on;
semilogy(phvec(1:nph),solmat(1:nph,3),'b-');
hold on;
semilogy(phvec(1:nph),solmat(1:nph,4),'g-');
hold off;
xlabel('pH');
ylabel('solution');
legend('Citrate','Fe','Ba','Nitrate')
%
%  plot error
%
figure(2)
semilogy(phvec(1:nph),fmat(1:nph),'k-');
xlabel('pH');
ylabel('average absolute error on f');

%
%  calculate other variables to Reproduce Figure 4 of reference
%
global k1 k2 k3 k4 k5 k6 k7 k8 k9 k10

solmat4 = zeros(nph,4);
for i = 1:1:nph
    H = 10.0^(-phvec(i));
    OH = 10.0^(-(14.0-phvec(i)));
    %Fe3p
    solmat4(i,1) =solmat(i,2);
    %FeOH2n
    solmat4(i,2) =solmat(i,2)*OH*k6;
    %FeHCitp
    solmat4(i,3)=solmat(i,2)*solmat(i,1)*H*(k4/k3);
    %FeCit
    solmat4(i,4)=solmat(i,2)*solmat(i,1)*k5;
end

figure(3)
plot(phvec(1:nph),solmat4(1:nph,1),'k-');
hold on;
plot(phvec(1:nph),solmat4(1:nph,2),'r-');
hold on;
plot(phvec(1:nph),solmat4(1:nph,3),'b-');
hold on;
plot(phvec(1:nph),solmat4(1:nph,4),'g-');
title('Fe Complexes')
xlabel('pH')
ylabel('Molarity')
legend('Fe','FeOH','FeHCit','FeCit')
hold off;

%  calculate other variables to Reproduce Figure 7 of reference

solmat5 = zeros(nph,5);
for i = 1:1:nph
    H = 10.0^(-phvec(i));
    OH = 10.0^(-(14.0-phvec(i)));
    %ba2p
    solmat5(i,1) =solmat(i,3);
    %bano3n
    solmat5(i,2) =solmat(i,3)*solmat(i,4)*k10;
    %bacitn
    solmat5(i,3)=solmat(i,3)*solmat(i,1)*k9;
    %bahcit
    solmat5(i,4)=solmat(i,3)*solmat(i,1)*H*(k8/k3);
    %bah2cit
    solmat5(i,5)=solmat(i,3)*solmat(i,1)*H^2*(k7/(k2*k3));
end

figure(4)
plot(phvec(1:nph),solmat5(1:nph,1),'k-');
hold on;
plot(phvec(1:nph),solmat5(1:nph,2),'r-');
hold on;
plot(phvec(1:nph),solmat5(1:nph,3),'b-');
hold on;
plot(phvec(1:nph),solmat5(1:nph,4),'g-');
hold on;
plot(phvec(1:nph),solmat5(1:nph,5),'m-');
title('Ba Complexes')
xlabel('pH')
ylabel('Molarity')
legend('Ba','BaNO','BaCit','BaHCit','BaH2Cit')
hold off;




